==> pySMS-2.0.6.tar.gz: pySMS-2.0.6/pySMS/html/pathdata/stockTabTable.py <==
stTableContainerInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td:nth-child(5) > div > table > tbody > tr > td.GLNOMTPDG5D'
stTableCheckBoxRowOddFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLotSerialFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableCheckBoxRowOddBack = ') > td.GLNOMTPDHM.GLNOMTPDEO > div > span > img'
stTableZSMSHoldBackOdd = ') > td.GLNOMTPDHM GLNOMTPDNO > div'
stTableProductFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLocationBackLocType = ') > td:nth-child(6) > div > table > tbody > tr > td.GLNOMTPDF5D'
stTableZSMSHoldInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td.GLNOMTPDHM.GLNOMTPDBP.GLNOMTPDNO > div'
stTableDescriptionBack = ') > td:nth-child(3) > div'
stTableCheckBoxRowEvenFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQAVFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLocationBackInfo = ') > td:nth-child(6) > div > table > tbody > tr > td.GLNOMTPDG5D > span'
stTableQRFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableDescriptionFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQAVBack = ') > td:nth-child(8) > div'
stTableCheckBoxInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td.GLNOMTPDHM.GLNOMTPDEO.GLNOMTPDBP > div > span > img'
stTableQOHFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLocationFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableZSMSHoldBackEven = ') > td.GLNOMTPDGM GLNOMTPDNO > div'
stTableLotSerialBack = ') > td:nth-child(4) > div'
stTableZSMSHoldFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQRBack = ') > td:nth-child(9) > div'
stTableQOHBack = ') > td:nth-child(7) > div'
stTableContainerFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableCheckBoxRowEvenBack = ') > td.GLNOMTPDGM.GLNOMTPDEO > div > span > img'
stTableProductBack = ') > td:nth-child(2) > span'
stTableContainerBackType = ') > td:nth-child(5) > div > table > tbody > tr > td.GLNOMTPDF5D'
stTableContainerBackInfo = ') > td:nth-child(5) > div > table > tbody > tr > td.GLNOMTPDG5D > span'

==> pySMS-3.1.0.tar.gz: pySMS-3.1.0/pySMS/html/pathdata/stockTabTable.py <==
stTableProductFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableProductBack = ') > td:nth-child(2) > span'
stTableDescriptionFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableDescriptionBack = ') > td:nth-child(3) > div'
stTableLotSerialFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLotSerialBack = ') > td:nth-child(4) > div'
stTableQOHFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQOHBack = ') > td:nth-child(7) > div'
stTableQAVFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQAVBack = ') > td:nth-child(8) > div'
stTableQRFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableQRBack = ') > td:nth-child(9) > div'
stTableContainerInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td:nth-child(5) > div > table > tbody > tr > td.GKCQ-U1BICE'
stTableContainerFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableContainerBackInfo = ') > td:nth-child(5) > div > table > tbody > tr > td.GKCQ-U1BICE > span'
stTableContainerBackType = ') > td:nth-child(5) > div > table > tbody > tr > td.GKCQ-U1BHCE'
stTableLocationFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableLocationBackInfo = ') > td:nth-child(6) > div > table > tbody > tr > td.GKCQ-U1BICE > span'
stTableLocationBackLocType = ') > td:nth-child(6) > div > table > tbody > tr > td.GKCQ-U1BHCE'
stTableZSMSHoldInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td.GKCQ-U1BHM.GKCQ-U1BBP.GKCQ-U1BNO > div'
stTableZSMSHoldFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableZSMSHoldBackEven = ') > td.GKCQ-U1BGM GKCQ-U1BNO > div'
stTableZSMSHoldBackOdd = ') > td.GKCQ-U1BHM GKCQ-U1BNO > div'
stTableCheckBoxInit = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child(1) > td.GKCQ-U1BHM.GKCQ-U1BEO.GKCQ-U1BBP > div > span > img'
stTableCheckBoxRowEvenFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableCheckBoxRowEvenBack = ') > td.GKCQ-U1BGM.GKCQ-U1BEO > div > span > img'
stTableCheckBoxRowOddFront = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
stTableCheckBoxRowOddBack = ') > td.GKCQ-U1BHM.GKCQ-U1BEO > div > span > img'
